@@ -23,6 +23,9 @@ use std::path;
 pub use zstd_safe::{CDict, DDict};
 
 /// Prepared dictionary for compression
+///
+/// A dictionary can include its own copy of the data (if it is `'static`), or it can merely point
+/// to a separate buffer (if it has another lifetime).
 pub struct EncoderDictionary<'a> {
     cdict: CDict<'a>,
 }
@@ -40,6 +43,7 @@ impl EncoderDictionary<'static> {
 
 impl<'a> EncoderDictionary<'a> {
     #[cfg(feature = "experimental")]
+    #[cfg_attr(feature = "doc-cfg", doc(cfg(feature = "experimental")))]
     /// Create prepared dictionary for compression
     ///
     /// A level of `0` uses zstd's default (currently `3`).
@@ -75,6 +79,7 @@ impl DecoderDictionary<'static> {
 
 impl<'a> DecoderDictionary<'a> {
     #[cfg(feature = "experimental")]
+    #[cfg_attr(feature = "doc-cfg", doc(cfg(feature = "experimental")))]
     /// Create prepared dictionary for decompression
     ///
     /// Only available with the `experimental` feature. Use `DecoderDictionary::copy` otherwise.
@@ -108,16 +113,8 @@ pub fn from_continuous(
     }
 
     let mut result = Vec::with_capacity(max_size);
-    unsafe {
-        result.set_len(max_size);
-        let written = zstd_safe::train_from_buffer(
-            &mut result,
-            sample_data,
-            sample_sizes,
-        )
+    zstd_safe::train_from_buffer(&mut result, sample_data, sample_sizes)
         .map_err(map_error_code)?;
-        result.set_len(written);
-    }
     Ok(result)
 }
 
